@@ -268,7 +268,7 @@ ms_container_read_markup (MSContainer const *c,
 	str_len = g_utf8_strlen (str, -1);
 
 	txo_run.last = G_MAXINT;
-	txo_run.accum = pango_attr_list_new ();
+	txo_run.accum = NULL;
 	for (txo_len -= 16 ; (gssize)txo_len >= 0 ; txo_len -= 8) {
 		guint16 o = GSF_LE_GET_GUINT16 (data + txo_len);
 		guint16 idx = GSF_LE_GET_GUINT16 (data + txo_len + 2);
@@ -277,9 +277,14 @@ ms_container_read_markup (MSContainer const *c,
 		txo_run.first = g_utf8_offset_to_pointer (str, o) - str;
 		XL_CHECK_CONDITION_VAL (txo_run.first < txo_run.last, txo_run.accum);
 
-		pango_attr_list_filter (ms_container_get_markup (c, idx),
-					(PangoAttrFilterFunc) append_txorun,
-					&txo_run);
+		if (idx != 0) {
+			if (!txo_run.accum)
+				txo_run.accum = pango_attr_list_new ();
+			pango_attr_list_filter
+				(ms_container_get_markup (c, idx),
+				 (PangoAttrFilterFunc) append_txorun,
+				 &txo_run);
+		}
 		txo_run.last = txo_run.first;
 	}
 	return txo_run.accum;
