@@ -758,10 +758,14 @@ xls_header_footer_import (GnmPrintHF **phf, const char *txt)
 
 	if (!hf)
 		*phf = hf = gnm_print_hf_new ("", "", "");
-
-	g_free (hf->left_format); hf->left_format = g_strdup ("");
-	g_free (hf->middle_format); hf->middle_format = g_strdup ("");
-	g_free (hf->right_format); hf->right_format = g_strdup ("");
+	else {
+		g_free (hf->left_format);
+		hf->left_format = g_strdup ("");
+		g_free (hf->middle_format);
+		hf->middle_format = g_strdup ("");
+		g_free (hf->right_format);
+		hf->right_format = g_strdup ("");
+	}
 
 	if (!txt)
 		return;
@@ -919,6 +923,7 @@ xls_collect_hlinks (GnmStyleList *sl, int max_col, int max_row)
 {
 	GHashTable *group = g_hash_table_new_full
 		(g_direct_hash, g_direct_equal, NULL, (GDestroyNotify)g_slist_free);
+	GList *keys, *k;
 
 	for (; sl != NULL ; sl = sl->next) {
 		GnmStyleRegion const *sr = sl->data;
@@ -939,6 +944,18 @@ xls_collect_hlinks (GnmStyleList *sl, int max_col, int max_row)
 				     g_slist_prepend (ranges, (gpointer)&sr->range));
 	}
 
+	keys = g_hash_table_get_keys (group);
+	for (k = keys; k ; k = k->next) {
+		GnmHLink *hlink = k->data;
+		GSList *ranges = g_hash_table_lookup (group, hlink);
+		GSList *nranges = g_slist_sort (ranges, (GCompareFunc)gnm_range_compare);
+		if (ranges != nranges) {
+			g_hash_table_steal (group, hlink);
+			g_hash_table_insert (group, hlink, nranges);
+		}
+	}
+	g_list_free (keys);
+
 	return group;
 }
 
