@@ -158,16 +158,6 @@ int excel_write_get_externsheet_idx (ExcelWriteState *wb,
 
 int excel_write_map_errcode (GnmValue const *v);
 
-/* Shared with xlsx export */
-typedef struct {
-	GnmValidation const *v;
-	GnmInputMsg *msg;
-	GSList	    *ranges;
-} XLValInputPair;
-GHashTable *excel_collect_validations  (GnmStyleList *ptr,
-					int max_col, int max_row);
-GHashTable *excel_collect_hlinks       (GnmStyleList *ptr,
-					int max_col, int max_row);
 GHashTable *excel_collect_pivot_caches (Workbook const *wb);
 
 void excel_sheet_extent (Sheet const *sheet, GnmRange *extent, GnmStyle **col_styles,
