@@ -90,11 +90,15 @@ xlsx_write_series_dim (XLSXWriteState *state, GsfXMLOut *xml, GogSeries const *s
 	int dim;
 	GOData const *dat;
 
-	for (dim = 0; dim < (int) desc->num_dim; dim++)
-		if (desc->dim[dim].ms_type == ms_type)
-			break;
-	if (dim == (int) desc->num_dim)
-		return;
+	if (ms_type == GOG_MS_DIM_LABELS)
+			dim = -1;
+	else {
+		for (dim = 0; dim < (int) desc->num_dim; dim++)
+			if (desc->dim[dim].ms_type == ms_type)
+				break;
+		if (dim == (int) desc->num_dim)
+			return;
+	}	
 	dat = gog_dataset_get_dim (GOG_DATASET (series), dim);
 	if (NULL != dat) {
 		GnmExprTop const *texpr = gnm_go_data_get_expr (dat);
@@ -349,16 +353,15 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style, const XLSXStyleContext
 		gsf_xml_out_end_element (xml); /* </a:prstGeom> */
 	}
 
-	if ((style->interesting_fields & GO_STYLE_FILL) &&
-	    (style->fill.type != GO_STYLE_FILL_NONE ||
-	     sctx->must_fill_fill)) {
+	if (style->interesting_fields & GO_STYLE_FILL) {
 		switch (style->fill.type) {
 		default:
 			g_warning ("invalid fill type, saving as none");
 		case GO_STYLE_FILL_IMAGE:
 			/* FIXME: export image */
 		case GO_STYLE_FILL_NONE:
-			gsf_xml_out_simple_element (xml, "a:noFill", NULL);
+			if (!style->fill.auto_type)
+				gsf_xml_out_simple_element (xml, "a:noFill", NULL);
 			break;
 		case GO_STYLE_FILL_PATTERN: {
 			const char *pattname = NULL;
@@ -690,6 +693,27 @@ xlsx_write_chart_text (XLSXWriteState *state, GsfXMLOut *xml,
 	g_free (text);
 }
 
+static void
+xlsx_write_layout (GsfXMLOut *xml, GogObject const *obj)
+{
+	unsigned pos = gog_object_get_position_flags (obj, GOG_POSITION_ANY_MANUAL);
+	if (pos & GOG_POSITION_MANUAL) {
+		/* FIXME: we suppose that the position is relative to start, and not absolute */
+		GogViewAllocation alloc;
+		gsf_xml_out_start_element (xml, "c:layout");
+		gsf_xml_out_start_element (xml, "c:manualLayout");
+		gog_object_get_manual_position ((GogObject *) obj, &alloc);
+		xlsx_write_chart_cstr_unchecked (xml, "c:xMode", "edge");
+		xlsx_write_chart_cstr_unchecked (xml, "c:yMode", "edge");
+		xlsx_write_chart_float (xml, "c:x", alloc.x);
+		xlsx_write_chart_float (xml, "c:y", alloc.y);
+		xlsx_write_chart_float (xml, "c:w", alloc.w);
+		xlsx_write_chart_float (xml, "c:h", alloc.h);
+		gsf_xml_out_end_element (xml); /* </c:manualLayout> */
+		gsf_xml_out_end_element (xml); /* </c:layout> */
+	}
+}
+
 static unsigned
 xlsx_get_axid (XLSXWriteState *state, GogAxis *axis)
 {
@@ -1253,7 +1277,39 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 	gsf_xml_out_end_element (xml); /* </c:plotArea> */
 
 	if ((obj = gog_object_get_child_by_name (chart, "Legend"))) {
+		char const *str;
+		unsigned pos = gog_object_get_position_flags (obj, GOG_POSITION_COMPASS);
 		gsf_xml_out_start_element (xml, "c:legend");
+		switch (pos) {
+		case GOG_POSITION_N:
+			str = "t";
+			break;
+		case GOG_POSITION_S:
+			str = "b";
+			break;
+		case GOG_POSITION_W:
+			str = "l";
+			break;
+		default:
+		case GOG_POSITION_E:
+			str = "r";
+			break;
+		case GOG_POSITION_N | GOG_POSITION_E:
+			str = "tr";
+			break;
+		case GOG_POSITION_N | GOG_POSITION_W:
+			str = "tl";
+			break;
+		case GOG_POSITION_S | GOG_POSITION_E:
+			str = "br";
+			break;
+		case GOG_POSITION_S | GOG_POSITION_W:
+			str = "bl";
+			break;
+		}
+		xlsx_write_chart_cstr_unchecked (xml, "c:legendPos", str);
+		xlsx_write_layout (xml, obj);
+		xlsx_write_go_style (xml, state, go_styled_object_get_style (GO_STYLED_OBJECT (obj)));
 		gsf_xml_out_end_element (xml); /* </c:legend> */
 	}
 	gsf_xml_out_end_element (xml); /* </c:chart> */
