@@ -258,15 +258,22 @@ gnumeric_randbetween (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float bottom = value_get_as_float (argv[0]);
 	gnm_float top = value_get_as_float (argv[1]);
+	gnm_float choices;
 
 	if (bottom > top)
 		return value_new_error_NUM (ei->pos);
 
-	/* Bottom is ceiled, top floored.  Neither is truncated.  */
+	// Bottom is ceiled, top floored.  We do this on the limits, not the
+	// resulting random number, in order to ensure all integers in the
+	// range have the same probability.  Tests show that Excel 2013 does
+	// the same thing.
 	bottom = gnm_ceil (bottom);
 	top = gnm_floor (top);
 
-	return value_new_float (bottom + gnm_floor ((top + 1.0 - bottom) * random_01 ()));
+	// Rounding alert: adding 1 could add 2 after rounding.
+	choices = gnm_ceil ((top - bottom) + 0.875);
+
+	return value_new_float (bottom + gnm_floor (choices * random_01 ()));
 }
 
 /***************************************************************************/
@@ -962,43 +969,45 @@ gnumeric_randstdist (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 /***************************************************************************/
 
+// Note: Most of the tests for these reside in sstest
+
 GnmFuncDescriptor const random_functions[] = {
 	{ "rand",    "", help_rand,
 	  gnumeric_rand, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
+	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbernoulli", "f",    help_randbernoulli,
 	  gnumeric_randbernoulli, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbeta", "ff",    help_randbeta,
 	  gnumeric_randbeta, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbetween", "ff",  help_randbetween,
 	  gnumeric_randbetween, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
+	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbinom", "ff",  help_randbinom,
 	  gnumeric_randbinom, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randcauchy", "f",    help_randcauchy,
 	  gnumeric_randcauchy, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randchisq", "f",    help_randchisq,
 	  gnumeric_randchisq, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "randdiscrete", "r|r",
 	  help_randdiscrete, gnumeric_randdiscrete, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "randexp", "f",          help_randexp,
 	  gnumeric_randexp, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randexppow", "ff",          help_randexppow,
 	  gnumeric_randexppow, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1006,11 +1015,11 @@ GnmFuncDescriptor const random_functions[] = {
         { "randfdist", "ff",       help_randfdist,
 	  gnumeric_randfdist, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randgamma", "ff",     help_randgamma,
 	  gnumeric_randgamma, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnormtail", "ff",     help_randnormtail,
 	  gnumeric_randnormtail, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1018,7 +1027,7 @@ GnmFuncDescriptor const random_functions[] = {
         { "randgeom", "f",     help_randgeom,
 	  gnumeric_randgeom, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randgumbel", "ff|f",     help_randgumbel,
 	  gnumeric_randgumbel, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1026,7 +1035,7 @@ GnmFuncDescriptor const random_functions[] = {
         { "randhyperg", "fff",     help_randhyperg,
 	  gnumeric_randhyperg, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randlandau", "", help_randlandau,
 	  gnumeric_randlandau, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1042,7 +1051,7 @@ GnmFuncDescriptor const random_functions[] = {
         { "randlog", "f",  help_randlog,
 	  gnumeric_randlog, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randlogistic", "f",  help_randlogistic,
 	  gnumeric_randlogistic, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1050,15 +1059,15 @@ GnmFuncDescriptor const random_functions[] = {
         { "randlognorm", "ff",  help_randlognorm,
 	  gnumeric_randlognorm, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnegbinom", "ff",  help_randnegbinom,
 	  gnumeric_randnegbinom, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnorm", "ff",  help_randnorm,
 	  gnumeric_randnorm, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randpareto", "ff",  help_randpareto,
 	  gnumeric_randpareto, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1066,11 +1075,11 @@ GnmFuncDescriptor const random_functions[] = {
         { "randpoisson", "f",  help_randpoisson,
 	  gnumeric_randpoisson, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randrayleigh", "f",  help_randrayleigh,
 	  gnumeric_randrayleigh, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randrayleightail", "ff",  help_randrayleightail,
 	  gnumeric_randrayleightail, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1078,7 +1087,7 @@ GnmFuncDescriptor const random_functions[] = {
         { "randsnorm", "|fff",  help_randsnorm,
 	  gnumeric_randsnorm, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randstdist", "ff",  help_randstdist,
 	  gnumeric_randstdist, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
@@ -1086,15 +1095,15 @@ GnmFuncDescriptor const random_functions[] = {
         { "randtdist", "f",  help_randtdist,
 	  gnumeric_randtdist, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randuniform", "ff",  help_randuniform,
 	  gnumeric_randuniform, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randweibull", "ff",  help_randweibull,
 	  gnumeric_randweibull, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
-	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "simtable", NULL,  help_simtable,
 	  NULL,	gnumeric_simtable, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
