@@ -1393,16 +1393,14 @@ style_dep_unrender (GnmDependent *dep, const char *what)
 	sheet_redraw_region (sheet,
 			     pos->col, pos->row,
 			     pos->col, pos->row);
-
-
 }
 
 static void
 style_dep_eval (GnmDependent *dep)
 {
 	/*
-	 * It is possible that the cell has been rendered between we ::changed
-	 * was called.
+	 * It is possible that the cell has been rendered between ::changed
+	 * was called and now.
 	 */
 	style_dep_unrender (dep, "being evaluated");
 }
@@ -2793,7 +2791,7 @@ dependents_invalidate_sheet (Sheet *sheet, gboolean destroy)
 void
 dependents_workbook_destroy (Workbook *wb)
 {
-	g_return_if_fail (IS_WORKBOOK (wb));
+	g_return_if_fail (GNM_IS_WORKBOOK (wb));
 	g_return_if_fail (wb->during_destruction);
 	g_return_if_fail (wb->sheets != NULL);
 
@@ -2862,7 +2860,7 @@ workbook_recalc (Workbook *wb)
 {
 	gboolean redraw = FALSE;
 
-	g_return_if_fail (IS_WORKBOOK (wb));
+	g_return_if_fail (GNM_IS_WORKBOOK (wb));
 
 	gnm_app_recalc_start ();
 
