@@ -61,7 +61,7 @@ cb_delete_cell_destroy (DeleteCellState *state)
 static void
 cb_delete_cell_ok_clicked (DeleteCellState *state)
 {
-	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
+	WorkbookControl *wbc = GNM_WBC (state->wbcg);
 	GtkWidget *radio_0;
 	int  cols, rows;
 	int i;
@@ -111,7 +111,7 @@ void
 dialog_delete_cells (WBCGtk *wbcg)
 {
 	DeleteCellState *state;
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
+	WorkbookControl *wbc = GNM_WBC (wbcg);
 	SheetView	*sv  = wb_control_cur_sheet_view (wbc);
 	Sheet *sheet = sv_sheet (sv);
 	GnmRange const *sel;
@@ -135,7 +135,7 @@ dialog_delete_cells (WBCGtk *wbcg)
 		return;
 	}
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, DELETE_CELL_DIALOG_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, DELETE_CELL_DIALOG_KEY))
 		return;
 	gui = gnm_gtk_builder_load ("delete-cells.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
@@ -166,7 +166,7 @@ dialog_delete_cells (WBCGtk *wbcg)
 					   state->wbcg,
 					   GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "helpbutton"),
 		GNUMERIC_HELP_LINK_DELETE_CELLS);
 
@@ -180,7 +180,7 @@ dialog_delete_cells (WBCGtk *wbcg)
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_delete_cell_destroy);
 
-	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       DELETE_CELL_DIALOG_KEY);
 	gtk_widget_show (state->dialog);
 }
