@@ -900,7 +900,7 @@ dialog_formula_guru_init (FormulaGuruState *state)
 							   "text", ARG_TYPE, NULL);
 	gtk_tree_view_append_column (state->treeview, column);
 	renderer = gnumeric_cell_renderer_expr_entry_new (state->wbcg);
-	state->cellrenderer = GNUMERIC_CELL_RENDERER_EXPR_ENTRY (renderer);
+	state->cellrenderer = GNM_CELL_RENDERER_EXPR_ENTRY (renderer);
 	g_signal_connect (G_OBJECT (renderer), "edited",
 			  G_CALLBACK (cb_dialog_formula_guru_edited), state);
 	state->editable = NULL;
@@ -963,7 +963,7 @@ dialog_formula_guru_init (FormulaGuruState *state)
 		"clicked",
 		G_CALLBACK (cb_dialog_formula_guru_cancel_clicked), state);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_FORMULA_GURU);
 
@@ -1004,7 +1004,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 
 	g_return_if_fail (wbcg != NULL);
 
-	dialog = gnumeric_dialog_raise_if_exists (wbcg, FORMULA_GURU_KEY);
+	dialog = gnm_dialog_raise_if_exists (wbcg, FORMULA_GURU_KEY);
 
 	if (dialog) {
 		/* We already exist */
@@ -1040,14 +1040,14 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 
 	state = g_new (FormulaGuruState, 1);
 	state->wbcg  = wbcg;
-	state->wb    = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
+	state->wb    = wb_control_get_workbook (GNM_WBC (wbcg));
 	state->gui   = gui;
 	state->active_path = NULL;
 	state->pos = g_new (GnmParsePos, 1);
 
 	gnm_expr_entry_disable_tips (wbcg_get_entry_logical (wbcg));
 
-	sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	sv = wb_control_cur_sheet_view (GNM_WBC (wbcg));
 	cell = sheet_cell_get (sv_sheet (sv), sv->edit_pos.col, sv->edit_pos.row);
 	if (cell != NULL) {
 		parse_pos_init_cell (state->pos, cell);
@@ -1095,7 +1095,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 		return;
 	}
 
-	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       FORMULA_GURU_KEY);
 
 	gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (state->dialog)));
