@@ -217,7 +217,7 @@ cb_tool_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 	    (GTK_TOGGLE_BUTTON (go_gtk_builder_get_widget (state->gui,"dont-change-formulae"))))
 		result |= PASTE_EXPR_LOCAL_RELOCATE;
 
-	cmd_paste_to_selection (WORKBOOK_CONTROL (state->wbcg), state->sv, result);
+	cmd_paste_to_selection (GNM_WBC (state->wbcg), state->sv, result);
 	gtk_widget_destroy (state->dialog);
 	return;
 }
@@ -226,7 +226,7 @@ static void
 cb_tool_paste_link_clicked (G_GNUC_UNUSED GtkWidget *button,
 			PasteSpecialState *state)
 {
-	cmd_paste_to_selection (WORKBOOK_CONTROL (state->wbcg), state->sv, PASTE_LINK);
+	cmd_paste_to_selection (GNM_WBC (state->wbcg), state->sv, PASTE_LINK);
 	gtk_widget_destroy (state->dialog);
 	return;
 }
@@ -238,7 +238,7 @@ dialog_paste_special (WBCGtk *wbcg)
 	GtkBuilder *gui;
 	char const * const *group;
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, GNM_PASTE_SPECIAL_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, GNM_PASTE_SPECIAL_KEY))
 		return;
 	gui = gnm_gtk_builder_load ("paste-special.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
@@ -249,7 +249,7 @@ dialog_paste_special (WBCGtk *wbcg)
 	state->gui    = gui;
 	state->dialog =  go_gtk_builder_get_widget (state->gui, "paste-special");
 	state->sheet = wbcg_cur_sheet (wbcg);
-	state->sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	state->sv = wb_control_cur_sheet_view (GNM_WBC (wbcg));
 
 	g_return_if_fail (state->dialog != NULL);
 
@@ -258,7 +258,7 @@ dialog_paste_special (WBCGtk *wbcg)
 			  "clicked",
 			  G_CALLBACK (cb_tool_paste_link_clicked), state);
 	state->help_button = go_gtk_builder_get_widget (state->gui, "help_button");
-	gnumeric_init_help_button (state->help_button, GNUMERIC_HELP_LINK_PASTE_SPECIAL);
+	gnm_init_help_button (state->help_button, GNUMERIC_HELP_LINK_PASTE_SPECIAL);
 	state->cancel_button = go_gtk_builder_get_widget (state->gui, "cancel_button");
 	g_signal_connect (G_OBJECT (state->cancel_button),
 			  "clicked",
@@ -289,7 +289,7 @@ dialog_paste_special (WBCGtk *wbcg)
 	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog), wbcg,
 					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 
-	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       GNM_PASTE_SPECIAL_KEY);
 
 	wbc_gtk_attach_guru (state->wbcg, state->dialog);
