@@ -56,14 +56,19 @@
 #define SOLVER_KEY            "solver-dialog"
 
 typedef struct {
+	int                 ref_count;
 	GtkBuilder          *gui;
 	GtkWidget           *dialog;
+	GtkWidget           *notebook;
 	GnmExprEntry	    *target_entry;
 	GnmExprEntry	    *change_cell_entry;
 	GtkWidget           *max_iter_entry;
 	GtkWidget           *max_time_entry;
+	GtkWidget           *gradient_order_entry;
 	GtkWidget           *solve_button;
 	GtkWidget           *close_button;
+	GtkWidget           *stop_button;
+	GtkWidget           *help_button;
 	GtkWidget           *add_button;
 	GtkWidget           *change_button;
 	GtkWidget           *delete_button;
@@ -80,17 +85,14 @@ typedef struct {
 
 	struct {
 		GnmSolver   *solver;
-		GtkDialog   *dialog;
 		GtkWidget   *timer_widget;
 		guint       timer_source;
 		GtkWidget   *status_widget;
 		GtkWidget   *problem_status_widget;
 		GtkWidget   *objective_value_widget;
-		GtkWidget   *stop_button;
-		GtkWidget   *ok_button;
-		gulong       sig_notify_result;
-		gulong       sig_notify_status;
-		gulong       sig_notify_reason;
+		guint       obj_val_source;
+		GtkWidget   *spinner;
+		guint        in_main;
 	} run;
 
 	Sheet		    *sheet;
@@ -359,8 +361,12 @@ cb_dialog_model_type_clicked (G_GNUC_UNUSED GtkWidget *button,
 }
 
 static void
-free_state (SolverState *state)
+unref_state (SolverState *state)
 {
+	state->ref_count--;
+	if (state->ref_count > 0)
+		return;
+
 	if (state->orig_params)
 		g_object_unref (state->orig_params);
 	g_free (state);
@@ -418,11 +424,14 @@ extract_settings (SolverState *state)
 		(GTK_SPIN_BUTTON (state->max_iter_entry));
 	param->options.max_time_sec = gtk_spin_button_get_value
 		(GTK_SPIN_BUTTON (state->max_time_entry));
+	param->options.gradient_order = gtk_spin_button_get_value
+		(GTK_SPIN_BUTTON (state->gradient_order_entry));
 
 	GET_BOOL_ENTRY ("autoscale_button", options.automatic_scaling);
 	GET_BOOL_ENTRY ("non_neg_button", options.assume_non_negative);
 	GET_BOOL_ENTRY ("all_int_button", options.assume_discrete);
 	GET_BOOL_ENTRY ("program", options.program_report);
+	GET_BOOL_ENTRY ("sensitivity", options.sensitivity_report);
 
 	g_free (param->options.scenario_name);
 	param->options.scenario_name = g_strdup
@@ -460,6 +469,11 @@ cb_dialog_solver_destroy (SolverState *state)
 {
 	g_return_if_fail (state != NULL);
 
+	if (state->run.solver) {
+		gnm_solver_stop (state->run.solver, NULL);
+		g_object_set (state->run.solver, "result", NULL, NULL);
+	}
+
 	extract_settings (state);
 
 	check_for_changed_options (state);
@@ -502,76 +516,31 @@ cb_stop_solver (SolverState *state)
 }
 
 static void
-cb_notify_status (SolverState *state)
+remove_timer_source (SolverState *state)
 {
-	GnmSolver *sol = state->run.solver;
-	const char *text;
-	gboolean finished = gnm_solver_finished (sol);
-	gboolean ok_ok = finished;
-
-	switch (sol->status) {
-	case GNM_SOLVER_STATUS_READY:
-		text = _("Ready");
-		break;
-	case GNM_SOLVER_STATUS_PREPARING:
-		text = _("Preparing");
-		break;
-	case GNM_SOLVER_STATUS_PREPARED:
-		text = _("Prepared");
-		break;
-	case GNM_SOLVER_STATUS_RUNNING:
-		text = _("Running");
-		if (sol->result) {
-			GnmSolverResultQuality q = sol->result->quality;
-			if (q == GNM_SOLVER_RESULT_FEASIBLE ||
-			    q == GNM_SOLVER_RESULT_OPTIMAL)
-				ok_ok = TRUE;
-		}
-		break;
-	case GNM_SOLVER_STATUS_DONE:
-		text = _("Done");
-		break;
-	default:
-	case GNM_SOLVER_STATUS_ERROR:
-		text = _("Error");
-		break;
-	case GNM_SOLVER_STATUS_CANCELLED:
-		text = _("Cancelled");
-		break;
+	if (state->run.timer_source) {
+		g_source_remove (state->run.timer_source);
+		state->run.timer_source = 0;
 	}
-
-	if (sol->reason) {
-		char *text2 = g_strconcat (text,
-					   " (", sol->reason, ")",
-					   NULL);
-		gtk_label_set_text (GTK_LABEL (state->run.status_widget),
-				    text2);
-		g_free (text2);
-	} else {
-		gtk_label_set_text (GTK_LABEL (state->run.status_widget), text);
-	}
-
-	if (finished) {
-		if (state->run.timer_source) {
-			g_source_remove (state->run.timer_source);
-			state->run.timer_source = 0;
-		}
-	}
-
-	gtk_widget_set_sensitive (state->run.stop_button, !finished);
-	gtk_widget_set_sensitive (state->run.ok_button, ok_ok);
 }
 
 static void
-cb_notify_result (SolverState *state)
+remove_objective_value_source (SolverState *state)
+{
+	if (state->run.obj_val_source) {
+		g_source_remove (state->run.obj_val_source);
+		state->run.obj_val_source = 0;
+	}
+}
+
+static void
+update_obj_value (SolverState *state)
 {
 	GnmSolver *sol = state->run.solver;
-	GnmSolverResult *r;
+	GnmSolverResult *r = sol->result;
+	char *valtxt;
 	const char *txt;
 
-	cb_notify_status (state);
-
-	r = sol->result;
 	switch (r ? r->quality : GNM_SOLVER_RESULT_NONE) {
 	default:
 	case GNM_SOLVER_RESULT_NONE:
@@ -597,14 +566,95 @@ cb_notify_result (SolverState *state)
 	gtk_label_set_text (GTK_LABEL (state->run.problem_status_widget), txt);
 
 	if (gnm_solver_has_solution (sol)) {
-		char *valtxt = gnm_format_value (go_format_general (),
+		txt = valtxt = gnm_format_value (go_format_general (),
 						 r->value);
-		gtk_label_set_text (GTK_LABEL (state->run.objective_value_widget),
-				    valtxt);
-		g_free (valtxt);
+	} else {
+		valtxt = NULL;
+		txt = "";
+	}
+
+	gtk_label_set_text (GTK_LABEL (state->run.objective_value_widget),
+			    txt);
+	g_free (valtxt);
+
+	remove_objective_value_source (state);
+}
+
+static void
+cb_notify_status (SolverState *state)
+{
+	GnmSolver *sol = state->run.solver;
+	const char *text;
+	gboolean finished = gnm_solver_finished (sol);
+	gboolean running = FALSE;
+
+	switch (sol->status) {
+	case GNM_SOLVER_STATUS_READY:
+		text = _("Ready");
+		break;
+	case GNM_SOLVER_STATUS_PREPARING:
+		text = _("Preparing");
+		break;
+	case GNM_SOLVER_STATUS_PREPARED:
+		text = _("Prepared");
+		break;
+	case GNM_SOLVER_STATUS_RUNNING:
+		text = _("Running");
+		running = TRUE;
+		break;
+	case GNM_SOLVER_STATUS_DONE:
+		text = _("Done");
+		break;
+	default:
+	case GNM_SOLVER_STATUS_ERROR:
+		text = _("Error");
+		break;
+	case GNM_SOLVER_STATUS_CANCELLED:
+		text = _("Cancelled");
+		break;
+	}
+
+	if (sol->reason) {
+		char *text2 = g_strconcat (text,
+					   " (", sol->reason, ")",
+					   NULL);
+		gtk_label_set_text (GTK_LABEL (state->run.status_widget),
+				    text2);
+		g_free (text2);
+	} else {
+		gtk_label_set_text (GTK_LABEL (state->run.status_widget), text);
+	}
+
+	gtk_widget_set_visible (state->run.spinner, running);
+	gtk_widget_set_visible (state->stop_button, !finished);
+	gtk_widget_set_sensitive (state->solve_button, finished);
+	gtk_widget_set_sensitive (state->close_button, finished);
+
+	if (state->run.obj_val_source)
+		update_obj_value (state);
+
+	if (finished) {
+		remove_timer_source (state);
+		if (state->run.in_main)
+			gtk_main_quit ();
 	}
 }
 
+static gboolean
+cb_obj_val_tick (SolverState *state)
+{
+	state->run.obj_val_source = 0;
+	update_obj_value (state);
+	return FALSE;
+}
+
+static void
+cb_notify_result (SolverState *state)
+{
+	if (state->run.obj_val_source == 0)
+		state->run.obj_val_source = g_timeout_add
+			(100, (GSourceFunc)cb_obj_val_tick, state);
+}
 
 static gboolean
 cb_timer_tick (SolverState *state)
@@ -633,7 +683,7 @@ static void
 create_report (GnmSolver *sol, SolverState *state)
 {
 	Sheet *sheet = state->sheet;
-	char *base = g_strdup_printf ("%s Report", sheet->name_unquoted);
+	char *base = g_strdup_printf (_("%s %%s Report"), sheet->name_unquoted);
 	gnm_solver_create_report (sol, base);
 	g_free (base);
 }
@@ -642,9 +692,6 @@ create_report (GnmSolver *sol, SolverState *state)
 static GnmSolverResult *
 run_solver (SolverState *state, GnmSolverParameters *param)
 {
-	GtkDialog *dialog;
-	GtkWidget *grid;
-	int dialog_res;
 	GError *err = NULL;
 	gboolean ok;
 	GnmSheetRange sr;
@@ -653,7 +700,8 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	GnmValue const *vinput;
 	GtkWindow *top = GTK_WINDOW (gtk_widget_get_toplevel (state->dialog));
 	GnmSolverResult *res = NULL;
-	int y;
+
+	state->ref_count++;
 
 	sol = gnm_solver_factory_functional (param->options.algorithm,
 					     state->wbcg)
@@ -665,6 +713,8 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 		goto fail;
 	}
 
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (state->notebook), -1);
+
 	state->run.solver = sol;
 
 	vinput = gnm_solver_param_get_input (param);
@@ -672,90 +722,22 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	if (!sr.sheet) sr.sheet = param->sheet;
 	undo = clipboard_copy_range_undo (sr.sheet, &sr.range);
 
-	dialog = (GtkDialog *)gtk_dialog_new_with_buttons
-		(_("Running Solver"),
-		 wbcg_toplevel (state->wbcg), 0,
-		 NULL, NULL);
-	state->run.stop_button =
-		go_gtk_dialog_add_button (dialog,
-					  _("Stop"),
-					  GTK_STOCK_STOP,
-					  GTK_RESPONSE_NO);
-	gtk_widget_set_tooltip_text
-		(state->run.stop_button,
-		 _("Stop the running solver"));
-	g_signal_connect_swapped (G_OBJECT (state->run.stop_button),
-				  "clicked", G_CALLBACK (cb_stop_solver),
+	g_signal_connect_swapped (G_OBJECT (sol),
+				  "notify::status",
+				  G_CALLBACK (cb_notify_status),
+				  state);
+	g_signal_connect_swapped (G_OBJECT (sol),
+				  "notify::reason",
+				  G_CALLBACK (cb_notify_status),
 				  state);
-
-	state->run.ok_button =
-		go_gtk_dialog_add_button (dialog,
-					  GNM_STOCK_OK,
-					  GTK_STOCK_OK,
-					  GTK_RESPONSE_YES);
-
-	grid = gtk_grid_new ();
-	g_object_set (grid,
-	              "column-spacing", 12,
-	              "row-spacing", 6,
-	              "border-width", 6,
-	              NULL);
-	for (y = 0; y < 4; y++) {
-		static const char *ltxt[4] = {
-			N_("Solver Status:"),
-			N_("Problem Status:"),
-			N_("Objective Value:"),
-			N_("Elapsed Time:")
-		};
-		GtkWidget *w;
-
-		w = gtk_label_new (_(ltxt[y]));
-		g_object_set (w,
-		              "halign", GTK_ALIGN_END,
-		              "valign", GTK_ALIGN_CENTER,
-		              NULL);
-		gtk_grid_attach (GTK_GRID (grid), w, 0, y, 1, 1);
-		w = gtk_label_new ("");
-		gtk_widget_set_size_request
-			(w,
-			 gnm_widget_measure_string (w, "0") * (10 + GNM_DIG),
-			 -1);
-		gtk_grid_attach (GTK_GRID (grid), w, 1, y, 1, 1);
-		switch (y) {
-		case 0: state->run.status_widget = w; break;
-		case 1: state->run.problem_status_widget = w; break;
-		case 2: state->run.objective_value_widget = w; break;
-		case 3: state->run.timer_widget = w; break;
-		default: g_assert_not_reached ();
-		}
-	}
-
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)),
-			    grid, TRUE, TRUE, 0);
-	gtk_widget_show_all (GTK_WIDGET (dialog));
-
-	state->run.sig_notify_status =
-		g_signal_connect_swapped (G_OBJECT (sol),
-					  "notify::status",
-					  G_CALLBACK (cb_notify_status),
-					  state);
-	state->run.sig_notify_reason =
-		g_signal_connect_swapped (G_OBJECT (sol),
-					  "notify::reason",
-					  G_CALLBACK (cb_notify_status),
-					  state);
 	cb_notify_status (state);
 
-	state->run.sig_notify_result =
-		g_signal_connect_swapped (G_OBJECT (sol),
-					  "notify::result",
-					  G_CALLBACK (cb_notify_result),
-					  state);
+	g_signal_connect_swapped (G_OBJECT (sol),
+				  "notify::result",
+				  G_CALLBACK (cb_notify_result),
+				  state);
 	cb_notify_result (state);
 
-	state->run.dialog = g_object_ref (dialog);
-	g_object_ref (state->run.timer_widget);
-	g_object_ref (state->run.status_widget);
 	state->run.timer_source = g_timeout_add_seconds
 		(1, (GSourceFunc)cb_timer_tick, state);
 	cb_timer_tick (state);
@@ -766,57 +748,33 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 			       GNM_WBC (state->wbcg),
 			       &err);
 	if (ok) {
-		dialog_res = go_gtk_dialog_run (dialog, top);
-		if (dialog_res == GTK_RESPONSE_YES && !sol->result)
-			dialog_res = GTK_RESPONSE_DELETE_EVENT;
-	} else {
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-		go_gtk_notice_dialog (top, GTK_MESSAGE_ERROR,
-				      "%s", err->message);
-		dialog_res = GTK_RESPONSE_DELETE_EVENT;
+		state->run.in_main++;
+		go_cmd_context_set_sensitive (GO_CMD_CONTEXT (state->wbcg), FALSE);
+		gtk_main ();
+		go_cmd_context_set_sensitive (GO_CMD_CONTEXT (state->wbcg), TRUE);
+		state->run.in_main--;
+		ok = gnm_solver_has_solution (sol);
+	} else if (err) {
+		gnm_solver_set_reason (sol, err->message);
 	}
+	g_clear_error (&err);
 
-	g_signal_handler_disconnect (G_OBJECT (sol),
-				     state->run.sig_notify_result);
-	g_signal_handler_disconnect (G_OBJECT (sol),
-				     state->run.sig_notify_status);
-	g_signal_handler_disconnect (G_OBJECT (sol),
-				     state->run.sig_notify_reason);
-
-	if (sol->status == GNM_SOLVER_STATUS_RUNNING)
-		gnm_solver_stop (sol, NULL);
+	remove_objective_value_source (state);
+	remove_timer_source (state);
 
 	/* ---------------------------------------- */
 
-	gtk_widget_destroy (GTK_WIDGET (state->run.dialog));
-	if (state->run.timer_source) {
-		g_source_remove (state->run.timer_source);
-		state->run.timer_source = 0;
-	}
-	g_object_unref (state->run.status_widget);
-	g_object_unref (state->run.timer_widget);
-	g_object_unref (state->run.dialog);
-
-	switch (dialog_res) {
-	default:
-	case GTK_RESPONSE_NO:
-	case GTK_RESPONSE_DELETE_EVENT:
-		break;
-
-	case GTK_RESPONSE_YES: {
+	if (ok) {
 		GOUndo *redo;
 
 		gnm_solver_store_result (sol);
 		redo = clipboard_copy_range_undo (sr.sheet, &sr.range);
 
-		if (param->options.program_report) {
+		if (param->options.program_report ||
+		    param->options.sensitivity_report) {
 			Workbook *wb = param->sheet->workbook;
 			GOUndo *undo_report, *redo_report;
 
-			/* This is a bit of overkill -- it just removes the
-			   sheet that create_report will add.  However, if
-			   in the future we add multiple sheets then this
-			   should still be good.  */
 			undo_report = go_undo_binary_new
 				(wb,
 				 workbook_sheet_state_new (wb),
@@ -841,8 +799,6 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 			     undo, redo);
 		res = g_object_ref (sol->result);
 		undo = redo = NULL;
-		break;
-	}
 	}
 
 fail:
@@ -854,6 +810,8 @@ fail:
 		state->run.solver = NULL;
 	}
 
+	unref_state (state);
+
 	return res;
 }
 
@@ -982,6 +940,8 @@ dialog_init (SolverState *state)
         if (state->dialog == NULL)
                 return TRUE;
 
+	state->notebook = go_gtk_builder_get_widget (state->gui, "solver_notebook");
+
 	/*  buttons  */
 	state->solve_button  = go_gtk_builder_get_widget (state->gui, "solvebutton");
 	g_signal_connect (G_OBJECT (state->solve_button), "clicked",
@@ -991,9 +951,8 @@ dialog_init (SolverState *state)
 	g_signal_connect (G_OBJECT (state->close_button), "clicked",
 			  G_CALLBACK (cb_dialog_close_clicked), state);
 
-	gnm_init_help_button (go_gtk_builder_get_widget (state->gui,
-							 "helpbutton"),
-				   GNUMERIC_HELP_LINK_SOLVER);
+	state->help_button = go_gtk_builder_get_widget (state->gui, "helpbutton");
+	gnm_init_help_button (state->help_button, GNUMERIC_HELP_LINK_SOLVER);
 
 	state->add_button  = go_gtk_builder_get_widget (state->gui, "addbutton");
 	gtk_button_set_alignment (GTK_BUTTON (state->add_button), 0.5, .5);
@@ -1011,6 +970,11 @@ dialog_init (SolverState *state)
 	g_signal_connect (G_OBJECT (state->delete_button), "clicked",
 			  G_CALLBACK (cb_dialog_delete_clicked), state);
 
+	state->stop_button = go_gtk_builder_get_widget (state->gui, "stopbutton");
+	g_signal_connect_swapped (G_OBJECT (state->stop_button),
+				  "clicked", G_CALLBACK (cb_stop_solver),
+				  state);
+
 	/* target_entry */
 	grid = GTK_GRID (go_gtk_builder_get_widget (state->gui,
 						 "parameter-grid"));
@@ -1074,6 +1038,11 @@ dialog_init (SolverState *state)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->max_time_entry),
 				   param->options.max_time_sec);
 
+	state->gradient_order_entry = go_gtk_builder_get_widget (state->gui,
+								 "gradient_order_entry");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->gradient_order_entry),
+				   param->options.gradient_order);
+
 	/* lhs_entry */
 	grid = GTK_GRID (go_gtk_builder_get_widget (state->gui,
 	                                            "constraints-grid"));
@@ -1176,6 +1145,7 @@ dialog_init (SolverState *state)
 	INIT_BOOL_ENTRY ("non_neg_button", options.assume_non_negative);
 	INIT_BOOL_ENTRY ("all_int_button", options.assume_discrete);
 	INIT_BOOL_ENTRY ("program", options.program_report);
+	INIT_BOOL_ENTRY ("sensitivity", options.sensitivity_report);
 
 	input = gnm_solver_param_get_input (param);
 	if (input != NULL)
@@ -1213,6 +1183,13 @@ dialog_init (SolverState *state)
 	gtk_entry_set_text (GTK_ENTRY (state->scenario_name_entry),
 			    param->options.scenario_name);
 
+	state->run.status_widget = go_gtk_builder_get_widget (state->gui, "solver_status_label");
+	state->run.problem_status_widget = go_gtk_builder_get_widget (state->gui, "problem_status_label");
+	state->run.objective_value_widget = go_gtk_builder_get_widget (state->gui, "objective_value_label");
+	state->run.timer_widget = go_gtk_builder_get_widget (state->gui, "elapsed_time_label");
+	state->run.spinner = go_gtk_builder_get_widget (state->gui, "run_spinner");
+
+
 /* Done */
 	gnm_expr_entry_grab_focus (state->target_entry, FALSE);
 	wbcg_set_entry (state->wbcg, state->target_entry);
@@ -1229,7 +1206,7 @@ dialog_init (SolverState *state)
 				  state);
 	g_object_set_data_full (G_OBJECT (state->dialog),
 				"state", state,
-				(GDestroyNotify)free_state);
+				(GDestroyNotify)unref_state);
 
 	return FALSE;
 }
@@ -1278,6 +1255,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 	}
 
 	state                 = g_new0 (SolverState, 1);
+	state->ref_count      = 1;
 	state->wbcg           = wbcg;
 	state->sheet          = sheet;
 	state->warning_dialog = NULL;
@@ -1287,7 +1265,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 	if (dialog_init (state)) {
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the Solver dialog."));
-		free_state (state);
+		unref_state (state);
 		return;
 	}
 
@@ -1295,7 +1273,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 
 	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
-			       SOLVER_KEY);
+			  SOLVER_KEY);
 
 	gtk_widget_show (state->dialog);
 }
