@@ -50,6 +50,7 @@
 #include "clipboard.h"
 #include "value.h"
 #include "expr.h"
+#include "expr-deriv.h"
 #include "parse-util.h"
 #include "rendered-value.h"
 #include "gnumeric-conf.h"
@@ -216,7 +217,6 @@ gnm_get_option_group (void)
 gchar const **
 gnm_pre_parse_init (int argc, gchar const **argv)
 {
-	const char *gnm_debug;
 /*
  * NO CODE BEFORE THIS POINT, PLEASE!
  *
@@ -252,12 +252,6 @@ gnm_pre_parse_init (int argc, gchar const **argv)
 #endif
 	}
 
-	/* We cannot use gnm_debug_flag yet.  See 627840.  */
-	gnm_debug = getenv ("GNM_DEBUG");
-	if (gnm_debug && strstr (gnm_debug, "gmemdebug")) {
-		g_mem_set_vtable (glib_mem_profiler_table);
-	}
-
 	/* On win32 argv contains 'ansi' encoded args.  We need to manually
 	 * pull in the real versions and convert them to utf-8 */
 	argv = go_shell_argv_to_glib_encoding (argc, argv);
@@ -385,6 +379,7 @@ gnm_shutdown (void)
 	dependent_types_shutdown ();
 	clipboard_shutdown ();
 	gnm_sheet_cell_shutdown ();
+	_gnm_expr_deriv_shutdown ();
 	_gnm_expr_shutdown ();
 	parse_util_shutdown ();
 	value_shutdown ();
