@@ -15,6 +15,8 @@
 #include "gnm-style-impl.h"
 #include "sheet-style.h"
 #include "style-conditions.h"
+#include "hlink.h"
+#include "input-msg.h"
 #include "application.h"
 #include "parse-util.h"
 #include "expr.h"
@@ -395,7 +397,7 @@ gnm_style_hash (gconstpointer style)
     : (elem == MSTYLE_CONDITIONS					\
     ? (a->conditions == b->conditions ||				\
        (a->conditions && b->conditions &&				\
-	gnm_style_conditions_equal (a->conditions, b->conditions)))	\
+	gnm_style_conditions_equal (a->conditions, b->conditions, FALSE)))	\
     : FALSE)))))))))))))))))))))))))
 
 /*
@@ -539,6 +541,54 @@ gnm_style_find_conflicts (GnmStyle *accum, GnmStyle const *overlay,
 	return conflicts;
 }
 
+#define GNM_INPUT_MSG_EQUAL3(a,b,r) (gnm_input_msg_equal (a,b))
+
+#define RELAX_CHECK(op_,field_,checker_) do {				\
+	if (diffs & (1u << (op_)) &&				\
+	    elem_is_set (a, (op_)) &&				\
+	    elem_is_set (b, (op_)) &&				\
+	    checker_ (a->field_, b->field_, relax_sheet))	\
+		diffs &= ~(1u << (op_));			\
+	} while (0)
+
+/**
+ * gnm_style_find_differences:
+ * @a: A #GnmStyle
+ * @b: A #GnmStyle
+ * @relax_sheet: if %TRUE, ignore differences solely caused by being linked into different sheets.
+ *
+ * Determine how two fully-qualified styles differ.
+ *
+ * Returns differences as a bitset of #GnmStyleElement.
+ **/
+unsigned int
+gnm_style_find_differences (GnmStyle const *a, GnmStyle const *b,
+			    gboolean relax_sheet)
+{
+	int i;
+	unsigned int diffs = 0;
+
+	g_assert (MSTYLE_ELEMENT_MAX <= CHAR_BIT * sizeof (diffs));
+
+	for (i = 0; i < MSTYLE_ELEMENT_MAX; i++) {
+		if (elem_is_set (a, i) != elem_is_set (b, i) ||
+		    (elem_is_set (a, i) && !elem_is_eq (a, b, i)))
+			diffs |= (1u << i);
+	}
+
+	if (relax_sheet) {
+		RELAX_CHECK (MSTYLE_HLINK, hlink, gnm_hlink_equal);
+		RELAX_CHECK (MSTYLE_VALIDATION, validation, gnm_validation_equal);
+		RELAX_CHECK (MSTYLE_INPUT_MSG, input_msg, GNM_INPUT_MSG_EQUAL3);
+		RELAX_CHECK (MSTYLE_CONDITIONS, conditions, gnm_style_conditions_equal);
+	}
+
+	return diffs;
+}
+
+#undef RELAX_CHECK
+#undef GNM_INPUT_MSG_EQUAL3
+
 static inline void
 gnm_style_clear_pango (GnmStyle *style)
 {
@@ -857,10 +907,17 @@ gnm_style_linked_sheet_changed (GnmStyle *style)
 		gnm_style_set_validation (style, new_v);
 	}
 
+	if (elem_is_set (style, MSTYLE_HLINK) &&
+	    style->hlink &&
+	    gnm_hlink_get_sheet (style->hlink) != sheet) {
+		GnmHLink *new_l = gnm_hlink_dup (style->hlink);
+		gnm_hlink_set_sheet (new_l, sheet);
+		gnm_style_set_hlink (style, new_l);
+	}
+
 	if (elem_is_set (style, MSTYLE_CONDITIONS) &&
-	    style->conditions
-	    && gnm_style_conditions_get_sheet (style->conditions) != sheet
-		) {
+	    style->conditions &&
+	    gnm_style_conditions_get_sheet (style->conditions) != sheet) {
 		GnmStyleConditions *new_c = gnm_style_conditions_dup (style->conditions);
 		gnm_style_conditions_set_sheet (new_c, sheet);
 		gnm_style_set_conditions (style, new_c);
@@ -1777,6 +1834,11 @@ gnm_style_get_contents_hidden (GnmStyle const *style)
 	return style->contents_hidden;
 }
 
+/**
+ * gnm_style_set_validation:
+ * @style: #GnmStyle
+ * @v: (transfer full): #GnmValidation
+ **/
 void
 gnm_style_set_validation (GnmStyle *style, GnmValidation *v)
 {
@@ -1803,15 +1865,22 @@ gnm_style_get_validation (GnmStyle const *style)
 	return style->validation;
 }
 
+/**
+ * gnm_style_set_hlink:
+ * @style: #GnmStyle
+ * @lnk: (transfer full): #GnmHLink
+ *
+ * This sets a link for @style.
+ **/
 void
-gnm_style_set_hlink (GnmStyle *style, GnmHLink *link)
+gnm_style_set_hlink (GnmStyle *style, GnmHLink *lnk)
 {
 	g_return_if_fail (style != NULL);
 
 	elem_clear_contents (style, MSTYLE_HLINK);
 	elem_changed (style, MSTYLE_HLINK);
 	elem_set (style, MSTYLE_HLINK);
-	style->hlink = link;
+	style->hlink = lnk;
 }
 
 /**
@@ -1829,6 +1898,13 @@ gnm_style_get_hlink (GnmStyle const *style)
 	return style->hlink;
 }
 
+/**
+ * gnm_style_set_input_msg:
+ * @style: #GnmStyle
+ * @msg: (transfer full): #GnmInputMsg
+ *
+ * This sets an input message for @style.
+ **/
 void
 gnm_style_set_input_msg (GnmStyle *style, GnmInputMsg *msg)
 {
@@ -1844,7 +1920,8 @@ gnm_style_set_input_msg (GnmStyle *style, GnmInputMsg *msg)
  * gnm_style_get_input_msg:
  * @style: #GnmStyle
  *
- * Returns: (transfer none):
+ * Returns: (transfer none): the currently set input message assuming
+ * that the style has such.
  **/
 GnmInputMsg *
 gnm_style_get_input_msg (GnmStyle const *style)
@@ -1855,6 +1932,13 @@ gnm_style_get_input_msg (GnmStyle const *style)
 	return style->input_msg;
 }
 
+/**
+ * gnm_style_set_conditions:
+ * @style: #GnmStyle
+ * @sc: (transfer full): #GnmStyleConditions
+ *
+ * This sets conditional style for @style.
+ **/
 void
 gnm_style_set_conditions (GnmStyle *style, GnmStyleConditions *sc)
 {
@@ -1870,7 +1954,8 @@ gnm_style_set_conditions (GnmStyle *style, GnmStyleConditions *sc)
  * gnm_style_get_conditions:
  * @style: #GnmStyle
  *
- * Returns: (transfer none):
+ * Returns: (transfer none): the currently set conditional style assuming
+ * that the style has such.
  **/
 GnmStyleConditions *
 gnm_style_get_conditions (GnmStyle const *style)
@@ -1995,6 +2080,13 @@ gnm_style_unlink_dependents (GnmStyle *style, GnmRange const *r)
 }
 
 
+/**
+ * gnm_style_visible_in_blank:
+ * @style: style to query
+ *
+ * Returns: %TRUE if the style is visible, i.e., not transparent.  Specifically
+ * that means if it has a background or a visible border.
+ */
 gboolean
 gnm_style_visible_in_blank (GnmStyle const *style)
 {
@@ -2233,6 +2325,14 @@ gnm_style_dump_border (GnmBorder *border, GnmStyleElement elem)
 		g_printerr ("blank\n");
 }
 
+/**
+ * gnm_style_dump:
+ * @style: style to dump
+ *
+ * This function dumps the given style's contents to stderr.  This is meant
+ * for debug purposes only and doesn't do a very good job for, for example,
+ * conditional style settings.
+ */
 void
 gnm_style_dump (GnmStyle const *style)
 {
