@@ -191,7 +191,7 @@ sv_is_colrow_selected (SheetView const *sv, int colrow, gboolean is_col)
 {
 	GSList *l;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
+	g_return_val_if_fail (GNM_IS_SV (sv), FALSE);
 
 	for (l = sv_selection_calc_simplification (sv);
 	     l != NULL; l = l->next) {
@@ -227,7 +227,7 @@ sv_is_full_colrow_selected (SheetView const *sv, gboolean is_cols, int index)
 	GSList *l;
 	gboolean found = FALSE;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
+	g_return_val_if_fail (GNM_IS_SV (sv), FALSE);
 
 	for (l = sv_selection_calc_simplification (sv);
 	     l != NULL; l = l->next){
@@ -262,7 +262,7 @@ sv_selection_col_type (SheetView const *sv, int col)
 	GnmRange const *sr;
 	int ret = COL_ROW_NO_SELECTION;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), COL_ROW_NO_SELECTION);
+	g_return_val_if_fail (GNM_IS_SV (sv), COL_ROW_NO_SELECTION);
 
 	if (sv->selections == NULL)
 		return COL_ROW_NO_SELECTION;
@@ -298,7 +298,7 @@ sv_selection_row_type (SheetView const *sv, int row)
 	GnmRange const *sr;
 	int ret = COL_ROW_NO_SELECTION;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), COL_ROW_NO_SELECTION);
+	g_return_val_if_fail (GNM_IS_SV (sv), COL_ROW_NO_SELECTION);
 
 	if (sv->selections == NULL)
 		return COL_ROW_NO_SELECTION;
@@ -364,7 +364,7 @@ sv_menu_enable_insert (SheetView *sv, gboolean col, gboolean row)
 {
 	int flags = 0;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 
 	if (sv->enable_insert_cols != col) {
 		flags |= MS_INSERT_COLS;
@@ -403,7 +403,7 @@ selection_first_range (SheetView const *sv,
 	GnmRange const *r;
 	GSList *l;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), NULL);
+	g_return_val_if_fail (GNM_IS_SV (sv), NULL);
 
 	l = sv->selections;
 
@@ -636,7 +636,7 @@ sv_selection_set (SheetView *sv, GnmCellPos const *edit,
 		  int base_col, int base_row,
 		  int move_col, int move_row)
 {
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 
 	sheet_selection_set_internal (sv, edit,
 		base_col, base_row,
@@ -688,7 +688,7 @@ sv_selection_add_full (SheetView *sv,
 	GnmRange *ss;
 	GnmCellPos edit;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 	sv_selection_simplify (sv);
 
 	/* Create and prepend new selection */
@@ -761,7 +761,7 @@ sv_selection_reset (SheetView *sv)
 {
 	GSList *list, *tmp;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 
 	/* Empty the sheets selection */
 	list = sv->selections;
@@ -1094,7 +1094,7 @@ sv_selection_apply (SheetView *sv, SelectionApplyFunc const func,
 	GSList *l;
 	GSList *proposed = NULL;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 
 	if (allow_intersection) {
 		for (l = sv_selection_calc_simplification (sv);
@@ -1154,7 +1154,7 @@ sv_selection_apply_in_order (SheetView *sv, SelectionApplyFunc const func,
 {
 	GSList *l, *reverse;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 
 	reverse = g_slist_copy (sv_selection_calc_simplification (sv));
 	reverse = g_slist_reverse (reverse);
@@ -1202,7 +1202,7 @@ sv_selection_foreach (SheetView *sv,
 {
 	GSList *l;
 
-	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
+	g_return_val_if_fail (GNM_IS_SV (sv), FALSE);
 
 	for (l = sv_selection_calc_simplification (sv); l != NULL; l = l->next) {
 		GnmRange *ss = l->data;
@@ -1339,7 +1339,7 @@ sv_selection_walk_step (SheetView *sv, gboolean forward, gboolean horizontal)
 	gboolean is_singleton = FALSE;
 	GSList *selections;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SV (sv));
 	g_return_if_fail (sv->selections != NULL);
 
 	selections = sv_selection_calc_simplification (sv);
