@@ -1,5 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
  * sheet-object.c: Implements the sheet object manipulation for Gnumeric
  *
@@ -69,6 +67,23 @@ sheet_object_anchor_get_type (void)
 	return t;
 }
 
+GType
+gnm_sheet_object_anchor_mode_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+	  static GEnumValue const values[] = {
+		  { GNM_SO_ANCHOR_TWO_CELLS, "GNM_SO_ANCHOR_TWO_CELLS", "two-cells" },
+		  { GNM_SO_ANCHOR_ONE_CELL, "GNM_SO_ANCHOR_ONE_CELL", "one-cell" },
+		  { GNM_SO_ANCHOR_ABSOLUTE, "GNM_SO_ANCHOR_ABSOLUTE", "absolute" },
+		  { 0, NULL, NULL }
+	  };
+	  etype = g_enum_register_static ("GnmSOAnchorMode", values);
+  }
+  return etype;
+}
+
+
 /* Returns the class for a SheetObject */
 #define SO_CLASS(so) GNM_SO_CLASS(G_OBJECT_GET_CLASS(so))
 
@@ -120,8 +135,16 @@ cb_so_snap_to_grid (SheetObject *so, SheetControl *sc)
 {
 	SheetObjectAnchor *snapped =
 		sheet_object_anchor_dup	(sheet_object_get_anchor (so));
+	GnmSOAnchorMode mode = snapped->mode;
+	snapped->mode = GNM_SO_ANCHOR_TWO_CELLS;
 	snapped->offset[0] = snapped->offset[1] = 0.;
 	snapped->offset[2] = snapped->offset[3] = 1.;
+	if (mode != GNM_SO_ANCHOR_TWO_CELLS) {
+		double pts[4];
+		sheet_object_anchor_to_pts (snapped, so->sheet, pts);
+		snapped->mode = mode;
+		sheet_object_pts_to_anchor (snapped, so->sheet, pts);
+	}
 	cmd_objects_move (sc_wbc (sc),
 		g_slist_prepend (NULL, so),
 		g_slist_prepend (NULL, snapped),
@@ -477,22 +500,43 @@ sheet_object_update_bounds (SheetObject *so, GnmCellPos const *pos)
 	    so->anchor.cell_bound.end.row < pos->row)
 		return;
 
-	/* Are all cols hidden ? */
-	end = so->anchor.cell_bound.end.col;
-	i = so->anchor.cell_bound.start.col;
-	while (i <= end && is_hidden)
-		is_hidden &= sheet_col_is_hidden (so->sheet, i++);
+	if (so->anchor.mode != GNM_SO_ANCHOR_TWO_CELLS) {
+		double x[4];
+		sheet_object_anchor_to_pts (&so->anchor, so->sheet, x);
+		sheet_object_pts_to_anchor (&so->anchor, so->sheet, x);
+	}
 
-	/* Are all rows hidden ? */
-	if (!is_hidden) {
-		is_hidden = TRUE;
-		end = so->anchor.cell_bound.end.row;
-		i = so->anchor.cell_bound.start.row;
+	switch (so->anchor.mode) {
+	default:
+	case GNM_SO_ANCHOR_TWO_CELLS:
+		/* Are all cols hidden ? */
+		end = so->anchor.cell_bound.end.col;
+		i = so->anchor.cell_bound.start.col;
 		while (i <= end && is_hidden)
-			is_hidden &= sheet_row_is_hidden (so->sheet, i++);
-		so->flags |= SHEET_OBJECT_IS_VISIBLE;
-	} else
+			is_hidden &= sheet_col_is_hidden (so->sheet, i++);
+
+		/* Are all rows hidden ? */
+		if (!is_hidden) {
+			is_hidden = TRUE;
+			end = so->anchor.cell_bound.end.row;
+			i = so->anchor.cell_bound.start.row;
+			while (i <= end && is_hidden)
+				is_hidden &= sheet_row_is_hidden (so->sheet, i++);
+		}
+		break;
+	case GNM_SO_ANCHOR_ONE_CELL:
+		/* Should we really hide if the row or column is hidden? */
+		is_hidden = sheet_col_is_hidden (so->sheet, so->anchor.cell_bound.start.col) ||
+				sheet_row_is_hidden (so->sheet, so->anchor.cell_bound.start.row);
+		break;
+	case GNM_SO_ANCHOR_ABSOLUTE:
+		is_hidden = FALSE;
+		break;
+	}
+	if (is_hidden)
 		so->flags &= ~SHEET_OBJECT_IS_VISIBLE;
+	else
+		so->flags |= SHEET_OBJECT_IS_VISIBLE;
 
 	g_signal_emit (so, signals [BOUNDS_CHANGED], 0);
 }
@@ -551,6 +595,12 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 
 	g_object_ref (so);
 	sheet->sheet_objects = g_slist_prepend (sheet->sheet_objects, so);
+	/* Update object bounds for absolute and one cell anchored objects */
+	if (so->anchor.mode != GNM_SO_ANCHOR_TWO_CELLS) {
+		double x[4];
+		sheet_object_anchor_to_pts (&so->anchor, sheet, x);
+		sheet_object_pts_to_anchor (&so->anchor, sheet, x);
+	}
 	/* FIXME : add a flag to sheet to have sheet_update do this */
 	sheet_objects_max_extent (sheet);
 
@@ -727,38 +777,60 @@ sheet_object_draw_cairo (SheetObject const *so, cairo_t *cr, gboolean rtl)
 		SheetObjectAnchor const *anchor;
 		double x = 0., y = 0., width, height, cell_width, cell_height;
 		anchor = sheet_object_get_anchor (so);
-		cell_width = sheet_col_get_distance_pts (so->sheet,
-					anchor->cell_bound.start.col,
-					anchor->cell_bound.start.col + 1);
-		cell_height = sheet_row_get_distance_pts (so->sheet,
-					anchor->cell_bound.start.row,
-					anchor->cell_bound.start.row + 1);
-		x = cell_width * anchor->offset[0];
-
-		y = cell_height * anchor->offset[1];
-		cell_width = sheet_col_get_distance_pts (so->sheet,
-					anchor->cell_bound.end.col,
-					anchor->cell_bound.end.col + 1);
-		cell_height = sheet_row_get_distance_pts (so->sheet,
-					anchor->cell_bound.end.row,
-					anchor->cell_bound.end.row + 1);
-
-		if (rtl) {
-			x = cell_width * (1 - anchor->offset[2]);
-		}
-		if (sheet_object_can_resize (so)) {
-			width = sheet_col_get_distance_pts (so->sheet,
+		if (anchor->mode == GNM_SO_ANCHOR_ABSOLUTE) {
+			x = anchor->offset[0];
+			y = anchor->offset[1];
+			if (sheet_object_can_resize (so)) {
+				width = anchor->offset[2];
+				height = anchor->offset[3];
+			} else
+				sheet_object_default_size ((SheetObject *) so, &width, &height);
+			if (rtl)
+				x = -x - width;
+		} else {
+			cell_width = sheet_col_get_distance_pts (so->sheet,
 						anchor->cell_bound.start.col,
-						anchor->cell_bound.end.col + 1);
-			height = sheet_row_get_distance_pts (so->sheet,
+						anchor->cell_bound.start.col + 1);
+			cell_height = sheet_row_get_distance_pts (so->sheet,
 						anchor->cell_bound.start.row,
-						anchor->cell_bound.end.row + 1);
-			width -= x;
-			height -= y;
-			width -= cell_width * (1. - anchor->offset[2]);
-			height -= cell_height * (1 - anchor->offset[3]);
-		} else
-			sheet_object_default_size ((SheetObject *) so, &width, &height);
+						anchor->cell_bound.start.row + 1);
+			x = cell_width * anchor->offset[0];
+
+			y = cell_height * anchor->offset[1];
+			if (anchor->mode == GNM_SO_ANCHOR_TWO_CELLS) {
+				cell_width = sheet_col_get_distance_pts (so->sheet,
+							anchor->cell_bound.end.col,
+							anchor->cell_bound.end.col + 1);
+				cell_height = sheet_row_get_distance_pts (so->sheet,
+							anchor->cell_bound.end.row,
+							anchor->cell_bound.end.row + 1);
+
+				if (rtl)
+					x = cell_width  * (1 - anchor->offset[2]);
+
+				if (sheet_object_can_resize (so)) {
+					width = sheet_col_get_distance_pts (so->sheet,
+								anchor->cell_bound.start.col,
+								anchor->cell_bound.end.col + 1);
+					height = sheet_row_get_distance_pts (so->sheet,
+								anchor->cell_bound.start.row,
+								anchor->cell_bound.end.row + 1);
+					width -= x;
+					height -= y;
+					width -= cell_width * (1. - ((rtl)? anchor->offset[0]: anchor->offset[2]));
+					height -= cell_height * (1 - anchor->offset[3]);
+				} else
+					sheet_object_default_size ((SheetObject *) so, &width, &height);
+			} else {
+				if (sheet_object_can_resize (so)) {
+					width = anchor->offset[2];
+					height = anchor->offset[3];
+				} else
+					sheet_object_default_size ((SheetObject *) so, &width, &height);
+				if (rtl)
+					x = cell_width  * (1 - anchor->offset[0]) - width;
+			}
+		}
 
 		/* we don't need to save/restore cairo, the caller must do it */
 		cairo_translate (cr, x, y);
@@ -863,23 +935,123 @@ sheet_object_anchor_to_pts (SheetObjectAnchor const *anchor,
 
 	r = &anchor->cell_bound;
 
-	res_pts [0] = sheet_col_get_distance_pts (sheet, 0,
-		r->start.col);
-	res_pts [2] = res_pts [0] + sheet_col_get_distance_pts (sheet,
-		r->start.col, r->end.col);
-	res_pts [1] = sheet_row_get_distance_pts (sheet, 0,
-		r->start.row);
-	res_pts [3] = res_pts [1] + sheet_row_get_distance_pts (sheet,
-		r->start.row, r->end.row);
+	if (anchor->mode != GNM_SO_ANCHOR_ABSOLUTE) {
+		res_pts [0] = sheet_col_get_distance_pts (sheet, 0,
+			r->start.col);
+		res_pts [1] = sheet_row_get_distance_pts (sheet, 0,
+			r->start.row);
+		if (anchor->mode == GNM_SO_ANCHOR_TWO_CELLS) {
+			res_pts [2] = res_pts [0] + sheet_col_get_distance_pts (sheet,
+				r->start.col, r->end.col);
+			res_pts [3] = res_pts [1] + sheet_row_get_distance_pts (sheet,
+				r->start.row, r->end.row);
 
-	res_pts [0] += cell_offset_calc_pt (sheet, r->start.col,
-		TRUE, anchor->offset [0]);
-	res_pts [1] += cell_offset_calc_pt (sheet, r->start.row,
-		FALSE, anchor->offset [1]);
-	res_pts [2] += cell_offset_calc_pt (sheet, r->end.col,
-		TRUE, anchor->offset [2]);
-	res_pts [3] += cell_offset_calc_pt (sheet, r->end.row,
-		FALSE, anchor->offset [3]);
+			res_pts [0] += cell_offset_calc_pt (sheet, r->start.col,
+				TRUE, anchor->offset [0]);
+			res_pts [1] += cell_offset_calc_pt (sheet, r->start.row,
+				FALSE, anchor->offset [1]);
+			res_pts [2] += cell_offset_calc_pt (sheet, r->end.col,
+				TRUE, anchor->offset [2]);
+			res_pts [3] += cell_offset_calc_pt (sheet, r->end.row,
+				FALSE, anchor->offset [3]);
+		} else {
+			res_pts [0] += cell_offset_calc_pt (sheet, r->start.col,
+				TRUE, anchor->offset [0]);
+			res_pts [1] += cell_offset_calc_pt (sheet, r->start.row,
+				FALSE, anchor->offset [1]);
+			res_pts[2] = res_pts [0] + anchor->offset [2];
+			res_pts[3] = res_pts [1] + anchor->offset [3];
+		}
+	} else {
+		res_pts [0] = anchor->offset [0];
+		res_pts [1] = anchor->offset [1];
+		res_pts[2] = res_pts [0] + anchor->offset [2];
+		res_pts[3] = res_pts [1] + anchor->offset [3];
+	}
+}
+
+void
+sheet_object_pts_to_anchor (SheetObjectAnchor *anchor,
+			    Sheet const *sheet, double const *res_pts)
+{
+	int col, row;
+	double x, y, tmp = 0;
+	ColRowInfo const *ci;
+	/* find end column */
+	col = x = 0;
+	do {
+		ci = sheet_col_get_info (sheet, col);
+		if (ci->visible) {
+			tmp = ci->size_pts;
+			if (res_pts[0] <= x + tmp)
+				break;
+			x += tmp;
+		}
+	} while (++col < gnm_sheet_get_last_col (sheet));
+	if (col == gnm_sheet_get_last_col (sheet)) {
+		/* not sure this will occur */
+		col--;
+		x -= tmp;
+	}
+	anchor->cell_bound.start.col = col;
+	anchor->offset[0] = (anchor->mode == GNM_SO_ANCHOR_ABSOLUTE)?
+		res_pts[0]: (res_pts[0] - x) / tmp;
+	/* find start row */
+	row = y = 0;
+	do {
+		ci = sheet_row_get_info (sheet, row);
+		if (ci->visible) {
+			tmp = ci->size_pts;
+			if (res_pts[1] <= y + tmp)
+				break;
+			y += tmp;
+		}
+	} while (++row < gnm_sheet_get_last_row (sheet));
+	if (row == gnm_sheet_get_last_row (sheet)) {
+		/* not sure this will occur */
+		row--;
+		y -= tmp;
+	}
+	anchor->cell_bound.start.row = row;
+	anchor->offset[1] = (anchor->mode == GNM_SO_ANCHOR_ABSOLUTE)?
+		res_pts[1]: (res_pts[1] - y) / tmp;
+
+	/* find end column */
+	do {
+		ci = sheet_col_get_info (sheet, col);
+		if (ci->visible) {
+			tmp = ci->size_pts;
+			if (res_pts[2] <= x + tmp)
+				break;
+			x += tmp;
+		}
+	} while (++col < gnm_sheet_get_last_col (sheet));
+	if (col == gnm_sheet_get_last_col (sheet)) {
+		/* not sure this will occur */
+		col--;
+		x -= tmp;
+	}
+	anchor->cell_bound.end.col = col;
+	anchor->offset[2] = (anchor->mode == GNM_SO_ANCHOR_TWO_CELLS)?
+		(res_pts[2] - x) / tmp: res_pts[2] - res_pts[0];
+	/* find end row */
+	do {
+		ci = sheet_row_get_info (sheet, row);
+		if (ci->visible) {
+			tmp = ci->size_pts;
+			if (res_pts[3] <= y + tmp)
+				break;
+			y += tmp;
+		}
+	} while (++row < gnm_sheet_get_last_row (sheet));
+	if (row == gnm_sheet_get_last_row (sheet)) {
+		/* not sure this will occur */
+		row--;
+		y -= tmp;
+	}
+	anchor->cell_bound.end.row = row;
+	anchor->offset[3] = (anchor->mode == GNM_SO_ANCHOR_TWO_CELLS)?
+		(res_pts[3] - y) / tmp: res_pts[3] - res_pts[1];
 }
 
 void
@@ -892,14 +1064,18 @@ sheet_object_anchor_to_offset_pts (SheetObjectAnchor const *anchor,
 
 	r = &anchor->cell_bound;
 
-	res_pts [0] = cell_offset_calc_pt (sheet, r->start.col,
-					   TRUE, anchor->offset [0]);
-	res_pts [1] = cell_offset_calc_pt (sheet, r->start.row,
-					   FALSE, anchor->offset [1]);
-	res_pts [2] = cell_offset_calc_pt (sheet, r->end.col,
-					   TRUE, anchor->offset [2]);
-	res_pts [3] = cell_offset_calc_pt (sheet, r->end.row,
-					   FALSE, anchor->offset [3]);
+	if (anchor->mode != GNM_SO_ANCHOR_ABSOLUTE) {
+		res_pts [0] = cell_offset_calc_pt (sheet, r->start.col,
+						   TRUE, anchor->offset [0]);
+		res_pts [1] = cell_offset_calc_pt (sheet, r->start.row,
+						   FALSE, anchor->offset [1]);
+		if (anchor->mode == GNM_SO_ANCHOR_TWO_CELLS) {
+			res_pts [2] = cell_offset_calc_pt (sheet, r->end.col,
+							   TRUE, anchor->offset [2]);
+			res_pts [3] = cell_offset_calc_pt (sheet, r->end.row,
+							   FALSE, anchor->offset [3]);
+		}
+	}
 }
 
 static void
@@ -965,7 +1141,8 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 		GnmRange r = so->anchor.cell_bound;
 
 		next = ptr->next;
-		if (update && 0 == (so->flags & SHEET_OBJECT_MOVE_WITH_CELLS))
+		if ((so->anchor.mode == GNM_SO_ANCHOR_ABSOLUTE) ||
+		    (update && 0 == (so->flags & SHEET_OBJECT_MOVE_WITH_CELLS)))
 			continue;
 		if (range_contains (&rinfo->origin, r.start.col, r.start.row)) {
 			/* FIXME : just moving the range is insufficent for all anchor types */
@@ -1178,6 +1355,7 @@ sheet_object_rubber_band_directly (G_GNUC_UNUSED SheetObject const *so)
  * @cell_bound: #GnmRange
  * @offsets: double[4]
  * @direction: #GODrawingAnchorDir
+ * @mode: #GnmSOAnchorMode
  *
  * A utility routine to initialize an anchor.  Useful in case we change fields
  * in the future and want to ensure that everything is initialized.
@@ -1185,7 +1363,8 @@ sheet_object_rubber_band_directly (G_GNUC_UNUSED SheetObject const *so)
 void
 sheet_object_anchor_init (SheetObjectAnchor *anchor,
 			  GnmRange const *r, const double *offsets,
-			  GODrawingAnchorDir direction)
+			  GODrawingAnchorDir direction,
+              GnmSOAnchorMode mode)
 {
 	int i;
 
@@ -1203,6 +1382,7 @@ sheet_object_anchor_init (SheetObjectAnchor *anchor,
 		anchor->offset[i] = offsets [i];
 
 	anchor->base.direction = direction;
+	anchor->mode = mode;
 	/* TODO : add sanity checking to handle offsets past edges of col/row */
 }
 
@@ -1266,6 +1446,19 @@ sheet_object_adjust_stacking (SheetObject *so, gint offset)
 	return cur - i;
 }
 
+void
+sheet_object_set_anchor_mode (SheetObject *so, GnmSOAnchorMode const *mode)
+{
+	/* FIXME: adjust offsets according to the old and new modes */
+	double pts[4];
+
+	if (so->anchor.mode == *mode)
+		return;
+	sheet_object_anchor_to_pts (&so->anchor, so->sheet, pts);
+	so->anchor.mode = *mode;
+	sheet_object_pts_to_anchor (&so->anchor, so->sheet, pts);
+}
+
 /*****************************************************************************/
 
 static GObjectClass *view_parent_class;
