@@ -128,6 +128,8 @@ struct GnmDiffState_ {
 
 	const GnmDiffActions *actions;
 
+	gboolean diff_found;
+
 	GsfOutput *output;
 
 	/* The following for xml mode.  */
@@ -487,7 +489,6 @@ xml_style_changed (GnmDiffState *state, GnmRange const *r,
 {
 	unsigned int conflicts;
 	GnmStyleElement e;
-	GnmStyle *os_copy;
 
 	xml_close_cells (state);
 
@@ -502,9 +503,7 @@ xml_style_changed (GnmDiffState *state, GnmRange const *r,
 	gsf_xml_out_add_uint (state->xml, "endCol", r->end.col);
 	gsf_xml_out_add_uint (state->xml, "endRow", r->end.row);
 
-	os_copy = gnm_style_dup (os);
-	conflicts = gnm_style_find_conflicts (os_copy, ns, 0);
-	gnm_style_unref (os_copy);
+	conflicts = gnm_style_find_differences (os, ns, TRUE);
 	for (e = 0; e < MSTYLE_ELEMENT_MAX; e++) {
 		if ((conflicts & (1u << e)) == 0)
 			continue;
@@ -677,7 +676,6 @@ xml_style_changed (GnmDiffState *state, GnmRange const *r,
 			DO_STRINGS ("Title", cb_validation_title, ov, nv);
 			DO_INTS ("AllowBlank", cb_validation_allow_blank, ov, nv);
 			DO_INTS ("UseDropdown", cb_validation_use_dropdown, ov, nv);
-			gsf_xml_out_add_cstr_unchecked (state->xml, NULL, "<!-- Difference might be spurious -->");
 			gsf_xml_out_end_element (state->xml); /* </Validation> */
 			break;
 		}
@@ -689,14 +687,12 @@ xml_style_changed (GnmDiffState *state, GnmRange const *r,
 			gsf_xml_out_start_element (state->xml, "InputMessage");
 			DO_STRINGS ("Message", gnm_input_msg_get_msg, om, nm);
 			DO_STRINGS ("Title", gnm_input_msg_get_title, om, nm);
-			gsf_xml_out_add_cstr_unchecked (state->xml, NULL, "<!-- Difference might be spurious -->");
 			gsf_xml_out_end_element (state->xml); /* </InputMessage> */
 			break;
 		}
 
 		case MSTYLE_CONDITIONS:
 			gsf_xml_out_start_element (state->xml, "Conditions");
-			gsf_xml_out_add_cstr_unchecked (state->xml, NULL, "<!-- Difference might be spurious -->");
 			gsf_xml_out_end_element (state->xml); /* </Conditions> */
 			break;
 
@@ -816,8 +812,30 @@ compare_corresponding_cells (GnmCell const *co, GnmCell const *cn)
 
 	if (has_expr != gnm_cell_has_expr (cn))
 		return TRUE;
-	if (has_expr)
-		return !gnm_expr_top_equal (co->base.texpr, cn->base.texpr);
+	if (has_expr) {
+		char *so, *sn;
+		GnmParsePos ppo, ppn;
+		gboolean eq;
+
+		if (gnm_expr_top_equal (co->base.texpr, cn->base.texpr))
+			return FALSE;
+
+		// Not equal, but with references to sheets, that is not
+		// necessary.  Compare as strings.
+
+		parse_pos_init_cell (&ppo, co);
+		so = gnm_expr_top_as_string (co->base.texpr, &ppo, sheet_get_conventions (co->base.sheet));
+
+		parse_pos_init_cell (&ppn, cn);
+		sn = gnm_expr_top_as_string (cn->base.texpr, &ppn, sheet_get_conventions (cn->base.sheet));
+
+		eq = g_strcmp0 (so, sn) == 0;
+
+		g_free (so);
+		g_free (sn);
+
+		return !eq;
+	}
 
 	if (has_value != (cn->value != NULL))
 		return TRUE;
@@ -873,17 +891,21 @@ diff_sheets_cells (GnmDiffState *state, Sheet *old_sheet, Sheet *new_sheet)
 			else if (order > 0)
 				co = NULL;
 			else {
-				if (compare_corresponding_cells (co, cn))
+				if (compare_corresponding_cells (co, cn)) {
+					state->diff_found = TRUE;
 					state->actions->cell_changed (state, co, cn);
+				}
 				io++, in++;
 				continue;
 			}
 		}
 
 		if (co) {
+			state->diff_found = TRUE;
 			state->actions->cell_changed (state, co, NULL);
 			io++;
 		} else if (cn) {
+			state->diff_found = TRUE;
 			state->actions->cell_changed (state, NULL, cn);
 			in++;
 		} else
@@ -896,9 +918,11 @@ diff_sheets_cells (GnmDiffState *state, Sheet *old_sheet, Sheet *new_sheet)
 
 #define DO_INT(field,attr)						\
 	do {								\
-		if (old_sheet->field != new_sheet->field)		\
+		if (old_sheet->field != new_sheet->field) {		\
+			state->diff_found = TRUE;			\
 			state->actions->sheet_attr_int_changed		\
 				(state, attr, old_sheet->field, new_sheet->field); \
+		}							\
 } while (0)
 
 static void
@@ -907,12 +931,16 @@ diff_sheets_attrs (GnmDiffState *state, Sheet *old_sheet, Sheet *new_sheet)
 	GnmSheetSize const *os = gnm_sheet_get_size (old_sheet);
 	GnmSheetSize const *ns = gnm_sheet_get_size (new_sheet);
 
-	if (os->max_cols != ns->max_cols)
+	if (os->max_cols != ns->max_cols) {
+		state->diff_found = TRUE;
 		state->actions->sheet_attr_int_changed
 			(state, "Cols", os->max_cols, ns->max_cols);
-	if (os->max_rows != ns->max_rows)
+	}
+	if (os->max_rows != ns->max_rows) {
+		state->diff_found = TRUE;
 		state->actions->sheet_attr_int_changed
 			(state, "Rows", os->max_rows, ns->max_rows);
+	}
 
 	DO_INT (display_formulas, "DisplayFormulas");
 	DO_INT (hide_zero, "HideZero");
@@ -943,9 +971,11 @@ cb_diff_sheets_styles_2 (G_GNUC_UNUSED gpointer key,
 	struct cb_diff_sheets_styles *data = user_data;
 	GnmRange r = sr->range;
 
-	if (gnm_style_equal (data->old_style, sr->style))
+	if (gnm_style_find_differences (data->old_style, sr->style, TRUE) == 0)
 		return;
 
+	data->state->diff_found = TRUE;
+
 	data->state->actions->style_changed (data->state, &r,
 					     data->old_sheet, data->new_sheet,
 					     data->old_style, sr->style);
@@ -1059,8 +1089,10 @@ diff (char const *oldfilename, char const *newfilename,
 		}
 	}
 
-	if (sheet_order_changed)
+	if (sheet_order_changed) {
+		state.diff_found = TRUE;
 		state.actions->sheet_order_changed (&state);
+	}
 
 	state.actions->diff_end (&state);
 
@@ -1076,10 +1108,13 @@ out:
 
 	gnm_pop_C_locale (locale);
 
+	if (res == 0)
+		res = state.diff_found ? 1 : 0;
+
 	return res;
 
 error:
-	res = 1;
+	res = 2;
 	goto out;
 }
 
@@ -1165,7 +1200,7 @@ main (int argc, char const **argv)
 		g_printerr (_("Usage: %s [OPTION...] %s\n"),
 			    g_get_prgname (),
 			    _("OLDFILE NEWFILE"));
-		res = 1;
+		res = 2;
 	}
 
 	/* Release cached string. */
