@@ -532,6 +532,19 @@ test_nonascii_numbers (void)
 
 /*-------------------------------------------------------------------------- */
 
+static char *random_summary = NULL;
+
+static void
+add_random_fail (const char *s)
+{
+	if (random_summary) {
+		char *t = g_strconcat (random_summary, ", ", s, NULL);
+		g_free (random_summary);
+		random_summary = t;
+	} else
+		random_summary = g_strdup (s);
+}
+
 static void
 define_cell (Sheet *sheet, int c, int r, const char *expr)
 {
@@ -620,7 +633,7 @@ rand_fractile_test (gnm_float const *vals, int N, int nf,
 
 	for (i = 1; i <= nf; i++) {
 		gnm_float T = expected[i];
-		if (!(gnm_abs (fractilecount[i] - T) <= 3 * gnm_sqrt (T))) {
+		if (!(gnm_abs (fractilecount[i] - T) <= 4 * gnm_sqrt (T))) {
 			g_printerr ("Fractile test failure for bin %d.\n", i);
 			ok = FALSE;
 		}
@@ -767,6 +780,10 @@ static void
 test_random_rand (int N)
 {
 	gnm_float mean, var, skew, kurt;
+	gnm_float mean_target = 0.5;
+	gnm_float var_target = 1.0 / 12;
+	gnm_float skew_target = 0;
+	gnm_float kurt_target = -6.0 / 5;
 	gnm_float *vals;
 	int i;
 	gboolean ok;
@@ -785,24 +802,24 @@ test_random_rand (int N)
 		}
 	}
 
-	T = 0.5;
-	if (gnm_abs (mean - T) > 0.01) {
-		g_printerr ("Mean failure [%.10" GNM_FORMAT_g "]\n", T);
+	T = mean_target;
+	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
-	T = 1.0 / 12;
+	T = var_target;
 	if (gnm_abs (var - T) > 0.01) {
-		g_printerr ("Var failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Var failure.\n");
 		ok = FALSE;
 	}
-	T = 0;
+	T = skew_target;
 	if (gnm_abs (skew - T) > 0.05) {
-		g_printerr ("Skew failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Skew failure.\n");
 		ok = FALSE;
 	}
-	T = -6.0 / 5;
+	T = kurt_target;
 	if (gnm_abs (kurt - T) > 0.05) {
-		g_printerr ("Kurt failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Kurt failure.\n");
 		ok = FALSE;
 	}
 
@@ -814,6 +831,8 @@ test_random_rand (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RAND");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -856,7 +875,7 @@ test_random_randuniform (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -892,6 +911,8 @@ test_random_randuniform (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDUNIFORM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -900,12 +921,16 @@ test_random_randuniform (int N)
 static void
 test_random_randbernoulli (int N)
 {
+	gnm_float p = 0.3;
+	gnm_float q = 1 - p;
 	gnm_float mean, var, skew, kurt;
+	gnm_float mean_target = p;
+	gnm_float var_target = p * (1 - p);
+	gnm_float skew_target = (q - p) / gnm_sqrt (p * q);
+	gnm_float kurt_target = (1 - 6 * p * q) / (p * q);
 	gnm_float *vals;
 	int i;
 	gboolean ok;
-	gnm_float p = 0.3;
-	gnm_float q = 1 - p;
 	char *expr;
 	gnm_float T;
 
@@ -923,35 +948,37 @@ test_random_randbernoulli (int N)
 		}
 	}
 
-	T = p;
+	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (mean - p) > 0.01) {
-		g_printerr ("Mean failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
-	T = p * (1 - p);
+	T = var_target;
 	g_printerr ("Expected var: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (var - T) > 0.01) {
-		g_printerr ("Var failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Var failure.\n");
 		ok = FALSE;
 	}
 
-	T = (q - p) / gnm_sqrt (p * q);
+	T = skew_target;
 	g_printerr ("Expected skew: %.10" GNM_FORMAT_g "\n", T);
-	if (gnm_abs (skew - T) > 0.05) {
-		g_printerr ("Skew failure [%.10" GNM_FORMAT_g "]\n", T);
+	if (!(gnm_abs (skew - T) <= 0.10 * gnm_abs (T))) {
+		g_printerr ("Skew failure.\n");
 		ok = FALSE;
 	}
 
-	T = (1 - 6 * p * q) / (p * q);
+	T = kurt_target;
 	g_printerr ("Expected kurt: %.10" GNM_FORMAT_g "\n", T);
-	if (gnm_abs (kurt - T) > 0.10) {
-		g_printerr ("Kurt failure [%.10" GNM_FORMAT_g "]\n", T);
+	if (!(gnm_abs (kurt - T) <= 0.15 * gnm_abs (T))) {
+		g_printerr ("Kurt failure.\n");
 		ok = FALSE;
 	}
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDBERNOULLI");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -988,7 +1015,7 @@ test_random_randdiscrete (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1018,6 +1045,8 @@ test_random_randdiscrete (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDDISCRETE");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1053,12 +1082,12 @@ test_random_randnorm (int N)
 
 	T = mean_target;
 	if (gnm_abs (mean - T) > 0.02) {
-		g_printerr ("Mean failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 	T = var_target;
 	if (gnm_abs (var - T) > 0.02) {
-		g_printerr ("Var failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Var failure.\n");
 		ok = FALSE;
 	}
 
@@ -1068,11 +1097,11 @@ test_random_randnorm (int N)
 	if (!rand_fractile_test (vals, N, nf, fractiles, NULL))
 		ok = FALSE;
 
-	if (adtest < 0.05) {
+	if (adtest < 0.01) {
 		g_printerr ("Anderson Darling Test rejected [%.10" GNM_FORMAT_g "]\n", adtest);
 		ok = FALSE;
 	}
-	if (cvmtest < 0.05) {
+	if (cvmtest < 0.01) {
 		g_printerr ("Cramér-von Mises Test rejected [%.10" GNM_FORMAT_g "]\n", cvmtest);
 		ok = FALSE;
 	}
@@ -1081,13 +1110,15 @@ test_random_randnorm (int N)
 			    lkstest);
 		ok = FALSE;
 	}
-	if (sftest < 0.05) {
+	if (sftest < 0.01) {
 		g_printerr ("Shapiro-Francia Test rejected [%.10" GNM_FORMAT_g "]\n", sftest);
 		ok = FALSE;
 	}
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDNORM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1124,14 +1155,14 @@ test_random_randsnorm (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (mean - T) > 0.01) {
-		g_printerr ("Mean failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
 	T = var_target;
 	g_printerr ("Expected var: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (var - T) > 0.01) {
-		g_printerr ("Var failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Var failure.\n");
 		ok = FALSE;
 	}
 
@@ -1139,19 +1170,21 @@ test_random_randsnorm (int N)
 	T = T*T*T*(4-M_PIgnum)/2;
 	g_printerr ("Expected skew: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (skew - T) > 0.05) {
-		g_printerr ("Skew failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Skew failure.\n");
 		ok = FALSE;
 	}
 
 	T = 2*(M_PIgnum - 3)*mean_target*mean_target*mean_target*mean_target/(var_target*var_target);
 	g_printerr ("Expected kurt: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_abs (kurt - T) > 0.15) {
-		g_printerr ("Kurt failure [%.10" GNM_FORMAT_g "]\n", T);
+		g_printerr ("Kurt failure.\n");
 		ok = FALSE;
 	}
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDSNORM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1191,7 +1224,7 @@ test_random_randexp (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1227,6 +1260,8 @@ test_random_randexp (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDEXP");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1267,7 +1302,7 @@ test_random_randgamma (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1303,6 +1338,8 @@ test_random_randgamma (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDGAMMA");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1314,7 +1351,8 @@ test_random_randbeta (int N)
 	gnm_float mean, var, skew, kurt;
 	gnm_float *vals;
 	gboolean ok;
-	gnm_float param_a = gnm_floor (1 / (0.0001 + gnm_pow (random_01 (), 6)));	gnm_float param_b = gnm_floor (1 / (0.0001 + gnm_pow (random_01 (), 6)));
+	gnm_float param_a = 1 / (0.0001 + gnm_pow (random_01 (), 6));
+	gnm_float param_b = 1 / (0.0001 + gnm_pow (random_01 (), 6));
 	gnm_float s = param_a + param_b;
 	gnm_float mean_target = param_a / s;
 	gnm_float var_target = mean_target * param_b / (s * (s + 1));
@@ -1345,7 +1383,7 @@ test_random_randbeta (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1381,6 +1419,8 @@ test_random_randbeta (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDBETA");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1392,7 +1432,7 @@ test_random_randtdist (int N)
 	gnm_float mean, var, skew, kurt;
 	gnm_float *vals;
 	gboolean ok;
-	gnm_float param_df = gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
+	gnm_float param_df = 1 + gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
 	gnm_float mean_target = 0;
 	gnm_float var_target = param_df > 2 ? param_df / (param_df - 2) : gnm_nan;
 	gnm_float skew_target = param_df > 3 ? 0 : gnm_nan;
@@ -1420,7 +1460,7 @@ test_random_randtdist (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_finite (var_target) && !(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1456,6 +1496,8 @@ test_random_randtdist (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDTDIST");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1467,8 +1509,8 @@ test_random_randfdist (int N)
 	gnm_float mean, var, skew, kurt;
 	gnm_float *vals;
 	gboolean ok;
-	gnm_float param_df1 = gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
-	gnm_float param_df2 = gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
+	gnm_float param_df1 = 1 + gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
+	gnm_float param_df2 = 1 + gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
 	gnm_float mean_target = param_df2 > 2 ? param_df2 / (param_df2 - 2) : gnm_nan;
 	gnm_float var_target = param_df2 > 4
 		? (2 * param_df2 * param_df2 * (param_df1 + param_df2 - 2) /
@@ -1499,7 +1541,7 @@ test_random_randfdist (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_finite (var_target) && !(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1535,6 +1577,8 @@ test_random_randfdist (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDFDIST");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1546,7 +1590,7 @@ test_random_randchisq (int N)
 	gnm_float mean, var, skew, kurt;
 	gnm_float *vals;
 	gboolean ok;
-	gnm_float param_df = gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
+	gnm_float param_df = 1 + gnm_floor (1 / (0.01 + gnm_pow (random_01 (), 6)));
 	gnm_float mean_target = param_df;
 	gnm_float var_target = param_df * 2;
 	gnm_float skew_target = gnm_sqrt (8 / param_df);
@@ -1574,7 +1618,7 @@ test_random_randchisq (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_finite (var_target) && !(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1610,6 +1654,8 @@ test_random_randchisq (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDCHISQ");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1654,7 +1700,7 @@ test_random_randcauchy (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_finite (var_target) && !(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1690,6 +1736,8 @@ test_random_randcauchy (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDCAUCHY");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1730,7 +1778,7 @@ test_random_randbinom (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1768,6 +1816,8 @@ test_random_randbinom (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDBINOM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1809,7 +1859,7 @@ test_random_randnegbinom (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1847,6 +1897,8 @@ test_random_randnegbinom (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDNEGBINOM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1892,7 +1944,7 @@ test_random_randhyperg (int N)
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (gnm_finite (var_target) &&
 	    !(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -1930,6 +1982,8 @@ test_random_randhyperg (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDHYPERG");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -1970,7 +2024,7 @@ test_random_randbetween (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2000,6 +2054,8 @@ test_random_randbetween (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDBETWEEN");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2039,7 +2095,7 @@ test_random_randpoisson (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2077,6 +2133,8 @@ test_random_randpoisson (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDPOISSON");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2119,7 +2177,7 @@ test_random_randgeom (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2157,6 +2215,8 @@ test_random_randgeom (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDGEOM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2205,7 +2265,7 @@ test_random_randlog (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2235,6 +2295,8 @@ test_random_randlog (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDLOG");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2282,7 +2344,7 @@ test_random_randweibull (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2318,6 +2380,8 @@ test_random_randweibull (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDWEIBULL");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2360,7 +2424,7 @@ test_random_randlognorm (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2396,6 +2460,8 @@ test_random_randlognorm (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDLOGNORM");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2436,7 +2502,7 @@ test_random_randrayleigh (int N)
 	T = mean_target;
 	g_printerr ("Expected mean: %.10" GNM_FORMAT_g "\n", T);
 	if (!(gnm_abs (mean - T) <= 3 * gnm_sqrt (var_target / N))) {
-		g_printerr ("Mean failure.\n");
+		g_printerr ("Mean failure [%.1" GNM_FORMAT_f " stdev]\n", (mean - T) / gnm_sqrt (var_target / N));
 		ok = FALSE;
 	}
 
@@ -2472,6 +2538,8 @@ test_random_randrayleigh (int N)
 
 	if (ok)
 		g_printerr ("OK\n");
+	else
+		add_random_fail ("RANDRAYLEIGH");
 	g_printerr ("\n");
 
 	g_free (vals);
@@ -2531,6 +2599,15 @@ test_random (void)
 
 #undef CHECK1
 
+	if (!single) {
+		if (random_summary)
+			g_printerr ("SUMMARY: FAIL for %s\n\n", random_summary);
+		else
+			g_printerr ("SUMMARY: OK\n\n");
+	}
+	g_free (random_summary);
+	random_summary = NULL;
+
 	mark_test_end (test_name);
 }
 
