@@ -510,6 +510,9 @@ value_new_from_string (GnmValueType t, char const *str, GOFormat *sf,
 		gnm_float d;
 
 		d = gnm_strto (str, &end);
+		if (d != 0 && d > -GNM_MIN && d < GNM_MIN)
+			errno = 0;
+
 		if (str != end && *end == '\0' && errno != ERANGE)
 			res = value_new_float (d);
 		break;
@@ -924,9 +927,12 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		return;
 
 	case VALUE_FLOAT:
-		g_string_append_printf (target, "%.*" GNM_FORMAT_g,
-					conv->output.decimal_digits,
-					v->v_float.val);
+		if (conv->output.decimal_digits < 0)
+			go_dtoa (target, "!" GNM_FORMAT_g, v->v_float.val);
+		else
+			g_string_append_printf (target, "%.*" GNM_FORMAT_g,
+						conv->output.decimal_digits,
+						v->v_float.val);
 		return;
 
 	case VALUE_ARRAY: {
