@@ -18,9 +18,8 @@ typedef struct {
 
 #define GNM_CCOMBO_VIEW_TYPE	 (gnm_ccombo_view_get_type ())
 #define GNM_CCOMBO_VIEW(o)		 (G_TYPE_CHECK_INSTANCE_CAST((o), GNM_CCOMBO_VIEW_TYPE, GnmCComboView))
-#define IS_GNM_CCOMBO_VIEW(o)	 (G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_CCOMBO_VIEW_TYPE))
+#define GNM_IS_CCOMBO_VIEW(o)	 (G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_CCOMBO_VIEW_TYPE))
 #define GNM_CCOMBO_VIEW_CLASS(k)	 (G_TYPE_CHECK_CLASS_CAST((k), GNM_CCOMBO_CComboViewClass))
-#define IS_GNM_CCOMBO_VIEW_CLASS(k)	 (G_TYPE_CHECK_CLASS_TYPE((k), GNM_CCOMBO_VIEW_TYPE))
 #define GNM_CCOMBO_VIEW_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GNM_CCOMBO_VIEW_TYPE, GnmCComboViewClass))
 
 GType gnm_ccombo_view_get_type (void);
