@@ -215,6 +215,7 @@ my @full_corpus =
      "$samples/format-tests.gnumeric",
      "$samples/formula-tests.gnumeric",
      "$samples/graph-tests.gnumeric",
+     "$samples/hlink-tests.gnumeric",
      "$samples/merge-tests.gnumeric",
      "$samples/names-tests.gnumeric",
      "$samples/number-tests.gnumeric",
@@ -873,7 +874,7 @@ sub quotearg1 {
     return "''" if $arg eq '';
     my $res = '';
     while ($arg ne '') {
-	if ($arg =~ m!^([-=/._a-zA-Z0-9]+)!) {
+	if ($arg =~ m!^([-=/._a-zA-Z0-9:]+)!) {
 	    $res .= $1;
 	    $arg = substr ($arg, length $1);
 	} else {
